package com.sosempresarial.tsc_blue_print;

import androidx.annotation.NonNull;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;

import com.example.tscdll.TSCActivity;
import com.example.tscdll.TscWifiActivity;

/** TscBluePrintPlugin */
public class TscBluePrint implements FlutterPlugin, MethodCallHandler {
  /// The MethodChannel that will the communication between Flutter and native Android
  ///
  /// This local reference serves to register the plugin with the Flutter Engine and unregister it
  /// when the Flutter Engine is detached from the Activity
  private MethodChannel channel;

  private static int paper_width = 50;
  private static int paper_height = 100;
  private static int speed = 4;
  private static int density = 15;
  private static int sensor = 0;
  private static int sensor_distance = 0;
  private static int sensor_offset = 0;

  TSCActivity TscDll = new TSCActivity();
  TscWifiActivity TscEthernetDll = new TscWifiActivity();

  @Override
  public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
    channel = new MethodChannel(flutterPluginBinding.getBinaryMessenger(), "tsc_blue_print");
    channel.setMethodCallHandler(this);
  }

  @Override
  public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
    if (call.method.equals("getPlatformVersion")) {
      result.success("Android " + android.os.Build.VERSION.RELEASE);
    } else if(call.method.equals("ble_print")) {

      @NonNull String ipAddress = call.argument("ipAddress");
      int widthPaper = call.argument("widthPaper");
      int heightPaper = call.argument("widthPaper");
      String tara = call.argument("tara");
      String peso = call.argument("peso");
      String bruto = call.argument("bruto");
      String fecha_prod = call.argument("fecha_prod");
      String vendor = call.argument("contact");
      String expiryDate = call.argument("expiryDate");
      String productCode = call.argument("productCode");

      try {

        TscDll.openport(ipAddress);
        //TscDll.setup(paper_width, paper_height, speed, density, sensor, sensor_distance, sensor_offset);
        TscDll.sendcommand("SIZE "+ widthPaper +" mm, "+ heightPaper +" mm\r\n");
        TscDll.sendcommand("GAP 4 mm, 6 mm\r\n");//Gap media
        //TscDll.sendcommand("BLINE 2 mm, 0 mm\r\n");//blackmark media

        TscDll.sendcommand("DIRECTION 0,0 \r\n");
        TscDll.sendcommand("REFERENCE 0,0 \r\n");
        TscDll.sendcommand("OFFSET 0 mm \r\n");

        TscDll.sendcommand("SPEED 4\r\n");
        TscDll.sendcommand("DENSITY 12\r\n");
        TscDll.sendcommand("CODEPAGE UTF-8\r\n");
        TscDll.sendcommand("SET TEAR ON\r\n");

        TscDll.clearbuffer();
        TscDll.sendcommand("TEXT 151,39,\"0\",180,9,9,\"Tara: "+ tara +"\"\n");
        TscDll.sendcommand("TEXT 354,39,\"0\",180,9,9,\"Bruto: "+ bruto +"\"\n");
        TscDll.sendcommand("TEXT 354,103,\"0\",180,8,8,\"" + productCode + "\"\n");
        TscDll.barcode(354, 140, "39", 32, 0, 180, 1, 3, ""+ productCode +"");
        TscDll.sendcommand("TEXT 354,68,\"0\",180,9,9,\"F.Prod: "+ fecha_prod +"\"\n");
        TscDll.sendcommand("TEXT 152,68,\"0\",180,9,9,\"Peso. "+ peso +"\"\n");
        TscDll.sendcommand("TEXT 60,184,\"0\",180,8,8,\"24922\"\n");
        TscDll.sendcommand("TEXT 354,184,\"0\",180,7,7, \"PEC. SAN FRANCISCO(MAIZALES)\"\n");

        TscDll.printlabel(1, 1);
        TscDll.closeport(5000);

      } catch (Exception ex){

      }

    } else if (call.method.equals("wifi_print")) {

      @NonNull String ipAddress = call.argument("ipAddress");
      int widthPaper = call.argument("widthPaper");
      int heightPaper = call.argument("widthPaper");
      String tara = call.argument("tara");
      String peso = call.argument("peso");
      String bruto = call.argument("bruto");
      String fecha_prod = call.argument("fecha_prod");
      String vendor = call.argument("contact");
      String expiryDate = call.argument("expiryDate");
      String productCode = call.argument("productCode");

      try {

        TscEthernetDll.openport(ipAddress,9100);
        //TscDll.setup(paper_width, paper_height, speed, density, sensor, sensor_distance, sensor_offset);
        TscEthernetDll.sendcommand("SIZE "+ widthPaper +" mm, "+ heightPaper +" mm\r\n");
        TscEthernetDll.sendcommand("GAP 4 mm, 6 mm\r\n");//Gap media
        //TscDll.sendcommand("BLINE 2 mm, 0 mm\r\n");//blackmark media

        TscEthernetDll.sendcommand("DIRECTION 0,0 \r\n");
        TscEthernetDll.sendcommand("REFERENCE 0,0 \r\n");
        TscEthernetDll.sendcommand("OFFSET 0 mm \r\n");

        TscEthernetDll.sendcommand("SPEED 4\r\n");
        TscEthernetDll.sendcommand("DENSITY 12\r\n");
        TscEthernetDll.sendcommand("CODEPAGE UTF-8\r\n");
        TscEthernetDll.sendcommand("SET TEAR ON\r\n");

        TscEthernetDll.clearbuffer();
        TscEthernetDll.sendcommand("TEXT 151,39,\"0\",180,9,9,\"Tara: "+ tara +"\"\n");
        TscEthernetDll.sendcommand("TEXT 354,39,\"0\",180,9,9,\"Bruto: "+ bruto +"\"\n");
        TscEthernetDll.sendcommand("TEXT 354,103,\"0\",180,8,8,\"" + productCode + "\"\n");
        TscEthernetDll.barcode(354, 140, "39", 32, 0, 180, 1, 3, ""+ productCode +"");
        TscEthernetDll.sendcommand("TEXT 354,68,\"0\",180,9,9,\"F.Prod: "+ fecha_prod +"\"\n");
        TscEthernetDll.sendcommand("TEXT 152,68,\"0\",180,9,9,\"Peso. "+ peso +"\"\n");
        TscEthernetDll.sendcommand("TEXT 60,184,\"0\",180,8,8,\"24922\"\n");
        TscEthernetDll.sendcommand("TEXT 354,184,\"0\",180,7,7, \"PEC. SAN FRANCISCO(MAIZALES)\"\n");

        TscDll.printlabel(1, 1);
        TscDll.closeport(5000);

      } catch (Exception ex) {

      }

    } else {
      result.notImplemented();
    }

  }

  @Override
  public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
    channel.setMethodCallHandler(null);
  }
}
